/*
			   Interface Statistics

	Gets interface statistics.

	The interface statistics are obtained from _PATH_PROC_NET_DEV,
	which by default, is defined as "/proc/net/dev".
 */

#ifndef IF_STAT_H
#define IF_STAT_H

#include <glib.h>


/*
 *	Interface Statistics:
 */
typedef struct {
	gulong		rx_bytes,		/* Total number of bytes
						 * received */
			rx_packets,		/* Total number of packets
						 * received */
			rx_errors,		/* Packets received with
                                                 * invalid or insufficient
                                                 * sizes */
			rx_dropped,		/* Packets discarded due to   
                                                 * insufficient system capacity
                                                 * or memory */
			rx_fifo,		/* Number of FIFO buffer errors */
			rx_frame,		/* Number of invalid packets
                                                 * received that are not
                                                 * multiples of 8 bits */
			rx_compressed,		/* Number of compressed packets
						 * received */
			rx_multicast,		/* Number of multicast frames
						 * received */
			tx_bytes,		/* Total number of bytes
						 * transmitted */
			tx_packets,		/* Total number of packets
						 * transmitted */
			tx_errors,		/* Packets encountered with
                                                 * invalid or insufficient
                                                 * sizes */
			tx_dropped,		/* Packets discarded due to
                                                 * insufficient system capacity
                                                 * or memory */
			tx_fifo,		/* Number of FIFO buffer errors */
			tx_colls,		/* Collisions, packets colliding
						 * while traversing the network,
						 * values greater than 0
						 * suggests network congesion */
			tx_carrier,		/* Digital to analog disruptions */
			tx_compressed;		/* Number of compressed packets
						 * transmitted */
} IFStat;
#define IFM_STATS(p)			((IFStat *)(p))


extern gint if_stat(
	const gchar *if_name,
	IFStat *stat_buf
);


#endif	/* IF_STAT_H */
