/*
		 Interface Monitor - Properties Dialog

	A properties dialog used to display interface information in
	more verbosity and detail.

	Note that the name of this dialog displayed to the user is
	the "Details Dialog" and not the "Properties Dialog".
 */

#ifndef IFM_PROP_DLG_H
#define IFM_PROP_DLG_H

#include <gtk/gtk.h>
#include "if_config.h"
#include "if_con_info.h"
#include "if_stat.h"
#include "route.h"
#include "ifm_win_pixmap.h"
#include "ifm_prop_dlg.h"


typedef struct _IFMPropDlg		IFMPropDlg;
#define IFM_PROP_DLG(p)			((IFMPropDlg *)(p))


extern IFMPropDlg *ifm_prop_dlg_new(
	const GdkRectangle *geometry
);
extern GtkWidget *ifm_prop_dlg_get_toplevel(IFMPropDlg *d);
extern void ifm_prop_dlg_set_interface_name(
	IFMPropDlg *d,
	const gchar *if_name
);
extern void ifm_prop_dlg_set_stats(
	IFMPropDlg *d,
	IFStat *stat_buf
);
extern void ifm_prop_dlg_record_history(
	IFMPropDlg *d,
	const gdouble elapsed_sec,
	const gfloat tx_coeff,
	const gfloat rx_coeff
);
extern void ifm_prop_dlg_set_state(
	IFMPropDlg *d,
	const gboolean state
);
extern void ifm_prop_dlg_set_interface_configuration(
	IFMPropDlg *d,
	const IFConfig *config
);
extern void ifm_prop_dlg_set_con_info(
	IFMPropDlg *d,
	const gchar *chat_report_path,
	const IFConInfo *con_info,
	const gulong bandwidth_bytes_per_sec,
	const gboolean user_set_bandwidth
);
extern void ifm_prop_dlg_route_table_append(
        IFMPropDlg *d,
        const RouteItem *item
);
extern void ifm_prop_dlg_route_table_clear(IFMPropDlg *d);
extern void ifm_prop_dlg_set_wm_icon(
	IFMPropDlg *d,
	IFMWinPixmap *p
);
extern void ifm_prop_dlg_set_state_icon(
	IFMPropDlg *d,
	IFMWinPixmap *p
);
extern void ifm_prop_dlg_update_display(IFMPropDlg *d);
extern gboolean ifm_prop_dlg_is_mapped(IFMPropDlg *d);
extern void ifm_prop_dlg_map(IFMPropDlg *d);
extern void ifm_prop_dlg_unmap(IFMPropDlg *d);
extern void ifm_prop_dlg_delete(IFMPropDlg *d);


#endif	/* IFM_PROP_DLG_H */
