#include <gtk/gtk.h>
#include "guiutils.h"
#include "ifm_win_pixmap.h"
#include "config.h"


IFMWinPixmap *ifm_win_pixmap_new(void);
IFMWinPixmap *ifm_win_pixmap_new_ref(void);
IFMWinPixmap *ifm_win_pixmap_new_from_xpm_data(
	GdkWindow *window,
	guint8 **xpm_data
);
IFMWinPixmap *ifm_win_pixmap_ref(IFMWinPixmap *p);
IFMWinPixmap *ifm_win_pixmap_unref(IFMWinPixmap *p);

gboolean ifm_win_pixmap_is_loaded(IFMWinPixmap *p);
	


#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)

#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)


/*
 *	Creates a new IFMWinPixmap.
 */
IFMWinPixmap *ifm_win_pixmap_new(void)
{
	return(IFM_WIN_PIXMAP(g_malloc0(sizeof(IFMWinPixmap))));
}

/*
 *	Creates a new IFMWinPixmap with one reference count.
 */
IFMWinPixmap *ifm_win_pixmap_new_ref(void)
{
	IFMWinPixmap *p = ifm_win_pixmap_new();
	if(p == NULL)
		return(p);

#if (IFM_DEBUG_LEVEL >= 2)
g_print("ifm_win_pixmap_new_ref(): p=%p\n", p);
#endif

	return(ifm_win_pixmap_ref(p));
}

/*
 *	Creates a new IFMWinPixmap with one reference count and loads
 *	the GdkPixmap from XPM data.
 */
IFMWinPixmap *ifm_win_pixmap_new_from_xpm_data(
	GdkWindow *window,
	guint8 **xpm_data
)
{
	IFMWinPixmap *p = ifm_win_pixmap_new_ref();
	if(p == NULL)
		return(p);

#if (IFM_DEBUG_LEVEL >= 2)
g_print("ifm_win_pixmap_new_from_xpm_data(): p=%p: xpm_data=%p\n", p, xpm_data);
#endif

	p->pixmap = gdk_pixmap_create_from_xpm_d(
		window,
		&p->mask,
		NULL,				/* No background color */
		(gchar **)xpm_data
	);
	if(p->pixmap != NULL)
	{
		gdk_window_get_size(
			(GdkWindow *)p->pixmap,
			&p->width, &p->height
		);
		p->src_data = (guint8 **)xpm_data;
	}

	return(p);
}

/*
 *	Adds a reference count to the IFMWinPixmap.
 */
IFMWinPixmap *ifm_win_pixmap_ref(IFMWinPixmap *p)
{
	if(p == NULL)
		return(p);

#if (IFM_DEBUG_LEVEL >= 2)
g_print("ifm_win_pixmap_ref(): p=%p\n", p);
#endif

	p->ref_count++;

	return(p);
}

/*
 *	Removes a reference count from the IFMWinPixmap, when the
 *	number of reference counts reach 0 then the IFMWinPixmap
 *	will be deleted.
 *
 *	This function always returns NULL.
 */
IFMWinPixmap *ifm_win_pixmap_unref(IFMWinPixmap *p)
{
	if(p == NULL)
		return(NULL);

#if (IFM_DEBUG_LEVEL >= 2)
g_print("ifm_win_pixmap_unref(): p=%p: p->ref_count=%i\n", p, p->ref_count);
#endif

	p->ref_count--;

	if(p->ref_count <= 0)
	{
#if (IFM_DEBUG_LEVEL >= 2)
g_print("ifm_win_pixmap_unref(): p=%p: ref_count has reached 0 and is deleted.\n", p);
#endif
		p->pixmap = GDK_PIXMAP_UNREF(p->pixmap);
		p->mask = GDK_BITMAP_UNREF(p->mask);
		g_free(p);
	}

	return(NULL);
}


/*
 *	Checks if the IFMWinPixmap is not NULL and has a loaded GdkPixmap.
 */
gboolean ifm_win_pixmap_is_loaded(IFMWinPixmap *p)
{
	if(p == NULL)
		return(FALSE);

	if(p->pixmap == NULL)
		return(FALSE);

	return(TRUE);
}
