/*
                              Route Table List

	Get route table.

	The route table is obtained in _PATH_PROC_NET_ROUTE, which by
	default, is defined as "/proc/net/route".
 */

#ifndef ROUTE_H
#define ROUTE_H

#include <glib.h>
#include "in_address.h"


/*
 *	Route Flags:
 *
 *	From linux/route.h RTF_*.
 */
typedef enum {
	ROUTE_FLAG_UP			= 0x0001,	/* Route is usable */
	ROUTE_FLAG_GATEWAY		= 0x0002,	/* Destination is a
							 * gateway */
	ROUTE_FLAG_HOST			= 0x0004,	/* Host entry
							 * (otherwise is net) */
	ROUTE_FLAG_REINSTATE		= 0x0008,	/* Reinstate route
							 * after timeout */
	ROUTE_FLAG_DYNAMIC		= 0x0010,	/* Created dynamic by
							 * redirect */
	ROUTE_FLAG_MODIFIED		= 0x0020,	/* Modified dynamic
							 * by redirect */
	ROUTE_FLAG_MTU			= 0x0040,	/* Was MSS for
							 * compatability */
	ROUTE_FLAG_WINDOW		= 0x0080,	/* Per route window
							 * clamping */
	ROUTE_FLAG_IRTT			= 0x0100,	/* Initial round trip
							 * time */
	ROUTE_FLAG_REJECT		= 0x0200
} RouteFlags;


/*
 *	Route Table Item:
 */
typedef struct {
	gchar		iface[80];		/* Name of interface */
	INAddress	destination,
			gateway;
	RouteFlags	flags;
	gulong		refcnt,
			use,
			metric;
	INAddress	mask;
	gulong		mtu,			/* Maximum transmit unit */
			window,			/* Per route window clamping */
			irtt;			/* Initial round trip time */
} RouteItem;
#define ROUTE_ITEM(p)			((RouteItem *)(p))


extern GList *route_table_list(void);
extern void route_table_list_delete(GList *list);


#endif	/* ROUTE_H */
