#include <errno.h>
#include <glib.h>
#include "if_config.h"


int main(int argc, char *argv[])
{
	gint status;
	const gchar *if_name = "lo";
	IFConfig config_buf;

	if(argc >= 2)
		if_name = argv[1];

	status = if_get_config(
		if_name,
		&config_buf
	);
	if(status != 0)
	{
		const gint error_code = (gint)errno;
		g_printerr(
			"%s: %s.\n",
			argv[1],
			g_strerror(error_code)
		);
	}
	else
	{
		g_print(
"link_encap=\"%s\"\n",
			config_buf.link_encap
		);
		g_print(
"hw_addr=%.2X:%.2X:%.2X:%.2X:%.2X:%.2X\n",
			config_buf.hw_addr.u8[0],
			config_buf.hw_addr.u8[1],
			config_buf.hw_addr.u8[2],
			config_buf.hw_addr.u8[3],
			config_buf.hw_addr.u8[4],
			config_buf.hw_addr.u8[5]
		);
		g_print(
"inet_addr=%d.%d.%d.%d\n",
			config_buf.inet_addr.u8[0],
			config_buf.inet_addr.u8[1],
			config_buf.inet_addr.u8[2],
			config_buf.inet_addr.u8[3]
		);
		g_print(
"bcast=%d.%d.%d.%d\n",
			config_buf.bcast.u8[0],
			config_buf.bcast.u8[1],
			config_buf.bcast.u8[2],
			config_buf.bcast.u8[3]
		);
		g_print(
"ptp=%d.%d.%d.%d\n",
			config_buf.ptp.u8[0],
			config_buf.ptp.u8[1],
			config_buf.ptp.u8[2],
			config_buf.ptp.u8[3]
		);
		g_print(
"mask=%d.%d.%d.%d\n",
			config_buf.mask.u8[0],
			config_buf.mask.u8[1],
			config_buf.mask.u8[2],
			config_buf.mask.u8[3]
		);

		g_print(
"mtu=%ld\n",
			config_buf.mtu
		);
		g_print(
"metric=%ld\n",
			config_buf.metric
		);

		g_print(
"flags=%s%s%s%s%s%s%s%s\n",
			(config_buf.flags & IF_CONFIG_FLAG_UP) ? "UP " : "",
			(config_buf.flags & IF_CONFIG_FLAG_LOOPBACK) ? "LOOPBACK " : "",
			(config_buf.flags & IF_CONFIG_FLAG_BROADCAST) ? "BROADCAST " : "",
			(config_buf.flags & IF_CONFIG_FLAG_POINTTOPOINT) ? "POINTTOPOINT " : "",
			(config_buf.flags & IF_CONFIG_FLAG_NOTRAILERS) ? "NOTRAILERS" : "",
			(config_buf.flags & IF_CONFIG_FLAG_RUNNING) ? "RUNNING " : "",
			(config_buf.flags & IF_CONFIG_FLAG_NOARP) ? "NOARP " : "",
			(config_buf.flags & IF_CONFIG_FLAG_MULTICAST) ? "MULTICAST " : ""
		);
		g_print(
"rx bytes=%ld packets=%ld dropped=%ld errors=%ld overruns=%ld frame=%ld\n",
			config_buf.rx_bytes, config_buf.rx_packets,
			config_buf.rx_dropped, config_buf.rx_errors,
			config_buf.rx_overruns, config_buf.rx_frame
		);
		g_print(
"tx bytes=%ld packets=%ld dropped=%ld errors=%ld overruns=%ld carrier=%ld\n\
collisions=%ld tx_queue_len=%ld\n",
			config_buf.tx_bytes, config_buf.tx_packets,
			config_buf.tx_dropped, config_buf.tx_errors,
			config_buf.tx_overruns, config_buf.tx_carrier,
			config_buf.collisions,
			config_buf.tx_queue_len
		);
		g_print(
"interrupt=%i\n",
			config_buf.interrupt
		);
		g_print(
"base_address=0x%.8X\n",
			config_buf.base_address.u32
		);
	}

	return(0);
}
